#
# spec file for package perl-Encode
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Encode
Version:        2.98
Release:        lp150.1.1
%define cpan_name Encode
Summary:        Character Encodings in Perl
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Encode/
Source0:        https://cpan.metacpan.org/authors/id/D/DA/DANKOGAI/%{cpan_name}-%{version}.tar.gz
Source1:        perl-Encode-rpmlintrc
Source2:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.81_01
BuildRequires:  perl(parent) >= 0.221
Requires:       perl(parent) >= 0.221
%{perl_requires}

%description
The 'Encode' module provides the interface between Perl strings and the
rest of the system. Perl strings are sequences of _characters_.

The repertoire of characters that Perl can represent is a superset of those
defined by the Unicode Consortium. On most platforms the ordinal values of
a character as returned by 'ord(_S_)' is the _Unicode codepoint_ for that
character. The exceptions are platforms where the legacy encoding is some
variant of EBCDIC rather than a superset of ASCII; see perlebcdic.

During recent history, data is moved around a computer in 8-bit chunks,
often called "bytes" but also known as "octets" in standards documents.
Perl is widely used to manipulate data of many types: not only strings of
characters representing human or computer languages, but also "binary"
data, being the machine's representation of numbers, pixels in an image, or
just about anything.

When Perl is processing "binary data", the programmer wants Perl to process
"sequences of bytes". This is not a problem for Perl: because a byte has
256 possible values, it easily fits in Perl's much larger "logical
character".

This document mostly explains the _how_. perlunitut and perlunifaq explain
the _why_.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
# MANUAL BEGIN
%__rm -f ${RPM_BUILD_ROOT}/usr/bin/enc2xs
%__rm -f ${RPM_BUILD_ROOT}/usr/bin/encguess
%__rm -f ${RPM_BUILD_ROOT}/usr/bin/piconv
%__rm -f ${RPM_BUILD_ROOT}/usr/share/man/man1/enc2xs.1*
%__rm -f ${RPM_BUILD_ROOT}/usr/share/man/man1/encguess.1*
%__rm -f ${RPM_BUILD_ROOT}/usr/share/man/man1/piconv.1*
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc AUTHORS Changes README

%changelog
* Mon Apr 23 2018 coolo@suse.com
- updated to 2.98
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Feb 22 2018 coolo@suse.com
- updated to 2.97
  see /usr/share/doc/packages/perl-Encode/Changes
* Mon Feb 12 2018 coolo@suse.com
- updated to 2.96
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed Jan 10 2018 coolo@suse.com
- updated to 2.94
  see /usr/share/doc/packages/perl-Encode/Changes
* Sun Oct  8 2017 coolo@suse.com
- updated to 2.93
  see /usr/share/doc/packages/perl-Encode/Changes
* Tue Jul 25 2017 coolo@suse.com
- updated to 2.92
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri Jun 23 2017 coolo@suse.com
- updated to 2.91
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed Jun 14 2017 coolo@suse.com
- updated to 2.90
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri May  5 2017 coolo@suse.com
- updated to 2.89
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Dec  1 2016 coolo@suse.com
- updated to 2.88
  see /usr/share/doc/packages/perl-Encode/Changes
* Sat Oct 29 2016 coolo@suse.com
- updated to 2.87
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Aug 11 2016 coolo@suse.com
- updated to 2.86
  see /usr/share/doc/packages/perl-Encode/Changes
* Fri Aug  5 2016 coolo@suse.com
- updated to 2.85
  see /usr/share/doc/packages/perl-Encode/Changes
* Tue Apr 12 2016 coolo@suse.com
- updated to 2.84
  see /usr/share/doc/packages/perl-Encode/Changes
* Mon Apr  4 2016 coolo@suse.com
- updated to 2.83
  see /usr/share/doc/packages/perl-Encode/Changes
* Sun Feb  7 2016 coolo@suse.com
- updated to 2.82
  see /usr/share/doc/packages/perl-Encode/Changes
* Wed Jan 27 2016 coolo@suse.com
- updated to 2.80
  see /usr/share/doc/packages/perl-Encode/Changes
* Thu Feb 26 2015 darin@darins.net
- update to 2.7.0
  + Makefile.PL
    add bin/encguess to EXE_FILES
  2.69 2015/02/05 10:35:11
  + bin/encguess
    Refactored so that
  * does not depend on non-core module (File::Slurp in particular)
  * PODified document
  * -s "encA encB" to -s encA,encB which is more shell-friendly
  * and more
  + MANIFEST
  + bin/encguess
    Pulled: Added CLI wrapper for Encode::Guess
    https://github.com/dankogai/p5-encode/pull/32
  + Unicode/Unicode.pm
    Pulled: Bump $VERSION in module changed since Encode-2.60
    https://github.com/dankogai/p5-encode/pull/31
  For a complete list of changes see:
    http://cpansearch.perl.org/src/DANKOGAI/Encode-2.70/Changes
* Fri Jan 25 2013 chris@computersalat.de
- update to 2.47
  * Encode.pm
    POD Fixes: Copyright and mail address
  * Makefile.PL
    Added LICENSE => 'perl'
  * lib/Encode/GSM0338.pm t/gsm0338.t
    REALLY fixed RT#75670: Wrong decoding for GSM 3.38 character \x09
    ucm/gsm0338.ucm is dropped from MANIFEST since 2.25
    but I was fixing the wrong file!
    https://rt.cpan.org/Ticket/Display.html?id=75670
* Tue Aug 23 2011 lars@linux-schulserver.de
- rename the binaries as they conflict with the same (but older)
  ones in the perl package itself
- add perl-Encode-rpmlintrc to the sources list
* Mon Aug 22 2011 lars@linux-schulserver.de
- update to 2.44:
  + fixed n-byte heap-overflow in Unicode.xs and decode_xs
  + use constant DEBUG option (cpan #69735)
* Tue May 31 2011 coolo@novell.com
- updated to 2.43
  Several bugfixes, see Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Aug 26 2010 pascal.bleser@opensuse.org
- initial package (2.39)
